"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validate = void 0;
const FernConfigurationSchema_1 = require("./schemas/FernConfigurationSchema");
const types_1 = require("./types");
function validate(files) {
    const validatedFiles = {};
    const failures = {};
    for (const [relativeFilePath, parsedFileContents] of Object.entries(files)) {
        const parsed = FernConfigurationSchema_1.FernConfigurationSchema.safeParse(parsedFileContents);
        if (parsed.success) {
            validatedFiles[relativeFilePath] = parsed.data;
        }
        else {
            failures[relativeFilePath] = {
                type: types_1.SyntaxAnalysisFailureType.STRUCTURE_VALIDATION,
                error: parsed.error,
            };
        }
    }
    if (Object.keys(failures).length > 0) {
        return {
            didSucceed: false,
            failures,
        };
    }
    else {
        return {
            didSucceed: true,
            validatedFiles,
        };
    }
}
exports.validate = validate;
