import yaml from "js-yaml";
import { SyntaxAnalysisFailureType } from "./types";
export async function parse(files) {
    const parsedFiles = {};
    const failures = {};
    function parseFilePath(file) {
        try {
            const parsed = yaml.load(file.fileContents);
            parsedFiles[file.filepath] = parsed;
        }
        catch (error) {
            failures[file.filepath] = {
                type: SyntaxAnalysisFailureType.FILE_PARSE,
                error,
            };
        }
    }
    await Promise.all(files.map(parseFilePath));
    if (Object.keys(failures).length > 0) {
        return {
            didSucceed: false,
            failures,
        };
    }
    else {
        return {
            didSucceed: true,
            files: parsedFiles,
        };
    }
}
