import { FernConfigurationSchema } from "./schemas/FernConfigurationSchema";
import { SyntaxAnalysisFailureType } from "./types";
export function validate(files) {
    const validatedFiles = {};
    const failures = {};
    for (const [relativeFilePath, parsedFileContents] of Object.entries(files)) {
        const parsed = FernConfigurationSchema.safeParse(parsedFileContents);
        if (parsed.success) {
            validatedFiles[relativeFilePath] = parsed.data;
        }
        else {
            failures[relativeFilePath] = {
                type: SyntaxAnalysisFailureType.STRUCTURE_VALIDATION,
                error: parsed.error,
            };
        }
    }
    if (Object.keys(failures).length > 0) {
        return {
            didSucceed: false,
            failures,
        };
    }
    else {
        return {
            didSucceed: true,
            validatedFiles,
        };
    }
}
